=============
``salt-call``
=============

Synopsis
========

::

    salt-call [options]

Options
=======

.. program:: salt-call

.. option:: -h, --help

    Print a usage message briefly summarizing these command-line options

.. option:: -g, --grains

    Return the information generated by the Salt grains

.. option:: -m MODULE_DIRS, --module-dirs=MODULE_DIRS

    Specify an additional directories to pull modules from, multiple
    directories can be delimited by commas

.. option:: -d, --doc

    Return the documentation for the specified module or for all modules if
    none are specified

.. option:: -l LOG_LEVEL, --log-level=LOG_LEVEL

    Console log level. One of ``info``, ``none``, ``garbage``,
    ``trace``, ``warning``, ``error``, ``debug``. For the logfile
    settings see the config file. Default: ``info``.

.. option::  --raw-out

    Print the output from the salt command in raw Python
    form, this is suitable for re-reading the output into
    an executing Python script with eval.

.. option::   --text-out

    Print the output from the salt command in the same
    form the shell would.

.. option::   --yaml-out

    Print the output from the salt command in YAML.

.. option::   --json-out

    Print the output from the salt command in JSON.

.. option:: --no-color

    Disable all colored output

See also
========

:manpage:`salt(1)`
:manpage:`salt-master(1)`
:manpage:`salt-minion(1)`
